@@ -1,6 +1,5 @@
 package pEFL::Ecore;
 
-use 5.028001;
 use strict;
 use warnings;
 use Carp;
@@ -88,6 +87,38 @@ our @EXPORT = qw(
 	ECORE_CAPS
 	ECORE_MODE
 	ECORE_LAST
+	ECORE_EVAS_OBJECT_ASSOCIATE_BASE
+	ECORE_EVAS_OBJECT_ASSOCIATE_STACK
+	ECORE_EVAS_OBJECT_ASSOCIATE_LAYER
+	ECORE_EVAS_OBJECT_ASSOCIATE_DEL
+	ECORE_EVAS_ENGINE_SOFTWARE_BUFFER
+  	ECORE_EVAS_ENGINE_SOFTWARE_XLIB
+  	ECORE_EVAS_ENGINE_XRENDER_X11
+   	ECORE_EVAS_ENGINE_OPENGL_X11
+   	ECORE_EVAS_ENGINE_SOFTWARE_XCB
+   	ECORE_EVAS_ENGINE_XRENDER_XCB
+   	ECORE_EVAS_ENGINE_SOFTWARE_GDI
+   	ECORE_EVAS_ENGINE_SOFTWARE_DDRAW
+   	ECORE_EVAS_ENGINE_DIRECT3D
+   	ECORE_EVAS_ENGINE_OPENGL_GLEW
+   	ECORE_EVAS_ENGINE_OPENGL_COCOA
+   	ECORE_EVAS_ENGINE_SOFTWARE_SDL
+   	ECORE_EVAS_ENGINE_DIRECTFB
+   	ECORE_EVAS_ENGINE_SOFTWARE_FB
+   	ECORE_EVAS_ENGINE_SOFTWARE_8_X11
+   	ECORE_EVAS_ENGINE_SOFTWARE_16_X11
+   	ECORE_EVAS_ENGINE_SOFTWARE_16_DDRAW
+   	ECORE_EVAS_ENGINE_SOFTWARE_16_WINCE
+   	ECORE_EVAS_ENGINE_OPENGL_SDL
+   	ECORE_EVAS_ENGINE_EWS
+   	ECORE_EVAS_ENGINE_PSL1GHT
+   	ECORE_EVAS_ENGINE_WAYLAND_SHM
+   	ECORE_EVAS_ENGINE_WAYLAND_EGL
+   	ECORE_EVAS_ENGINE_DRM
+   	ECORE_EVAS_ENGINE_OPENGL_DRM
+	ECORE_EVAS_AVOID_DAMAGE_NONE
+	ECORE_EVAS_AVOID_DAMAGE_EXPOSE
+	ECORE_EVAS_AVOID_DAMAGE_BUILT_IN
 );
 
 
